# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-02-08 08:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('admin_honeypot', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='loginattempt',
            name='ip_address',
            field=models.GenericIPAddressField(blank=True, null=True, verbose_name='ip address'),
        ),
    ]
